<?php
/*
Plugin Name: wp-pannellum
Plugin URI: http://okiraku-camera.tokyo/blog/?page_id=7780
Version: 0.2
Author: okiraku-camera.tokyo
Author URI: https://okiraku-camera.tokyo/blog/
Description: Just antoher simple panorama plugin for WordPress, using "pannellum 2.4.0 (https://pannellum.org/) "

 * Copyright (c) 2018 okiraku-camera.tokyo
 * Licensed under MIT license:
 * http://www.opensource.org/licenses/mit-license.php
 *
*/

function wp_pannellum_scripts() {
	wp_enqueue_style('pannellum-style', plugins_url( 'pannellum/pannellum.css', __FILE__));
	wp_enqueue_style('wp-pannellum-style', plugins_url( 'style.css', __FILE__));
	wp_enqueue_script('pannellum-js', plugins_url( 'pannellum/pannellum.js', __FILE__));
}
add_action('wp_enqueue_scripts','wp_pannellum_scripts');

function wp_pannellum_func( $atts ) {
 global $content_width;
	$atts = shortcode_atts(
		array(
			'type' => 'equirectangular',
			'title' => '',
			'hfov' => 60,
			'minhfov' => 45,
			'maxhfov' => 120,
			'haov' => 360,
			'vaov' => 180,
			'voffset' => 0,
			'autorotate' => 0,
			'pitch' => 0,
			'yaw' => 0,
			'minpitch' => -90,
			'maxpitch' => 90,
			'minyaw' => -180,
			'maxyaw' => 180,
			'autoload' => 'false',
			'autorotateinactivitydelay' => 2000,
			'showzoomctrl' => 'true',
			'showfullscreenctrl' => 'true',
			'hide_ctrls' => '',
			'url' => '',
			'attachment_id' => '',
			'aspect_ratio' => 0,
			'sample_image' => '',
			'popup_view' => '',
			'anchor_text' => 'popup panorama'
		), $atts, 'wp_pannellum' );	

	if ($atts['sample_image'] !== '')
		$atts['url'] = plugins_url('samples/' . $atts['sample_image'], __FILE__);
	else if ($atts['attachment_id'] !== '')
		$atts['url'] = wp_get_attachment_url($atts['attachment_id'], 'full' );

	static $div_seq = 0;
	$div_seq++;
	$pannellum_div = 'wp_pannellum_' . $div_seq;
	$pano_config = 'pano_' . $div_seq;
	$ratio = 0.66;
	if ($atts['aspect_ratio'] > 0 && $atts['aspect_ratio'] <= 100)
		$ratio= $atts['aspect_ratio'] / 100;
	$cw = 576;
	if (isset($content_width))
		$cw = $content_width;
	if ($atts['hide_ctrls'] !== '') {
		$atts['showzoomctrl'] = 'false';
		$atts['showfullscreenctrl'] = 'false';
	}

	ob_start();
	if ($atts['popup_view'] === '')
		echo "<div id='" . $pannellum_div . "' style='margin:0 auto;'></div>\n";
?>
	<script>
		<?php if ($div_seq == 1) { ?>
		jQuery(function() {
		jQuery('#wp_pannellum_bg, #wp_pannellum_close').click(function(e) { jQuery('#wp_pannellum_popup, #wp_pannellum_bg').hide();});});
		function show_pannellum(panorama_div, panorama_config, popup_view, a_ratio) {
			if (popup_view !== '') {
				var w = Math.min(jQuery(document).width(), 1260) * 0.95;
				var h = w * a_ratio;
				jQuery('#wp_pannellum_popup').css({
        		    'position':'absolute',
		            'left':jQuery(window).scrollLeft() + 10 + 'px',
        		    'top':jQuery(window).scrollTop() ,
					'z-index':9998,
					'width': w + 'px',
					'height': h + 'px'
        		});
				jQuery('#wp_pannellum_bg').css({
        		    'position':'absolute',
					'left':0,
					'top':0,
					'width':jQuery(document).width(),
					'height':jQuery(document).height(),
					'z-index':9900
				});
				jQuery('#panorama').empty();
				jQuery('#wp_pannellum_popup, #wp_pannellum_bg').show();
			} else {
				var pw = jQuery('#' + panorama_div).parent().width();
				var w = Math.min(pw, <?php echo $cw; ?>);
				// var w = <?php echo $cw; ?>;
				var h = w * a_ratio;
				jQuery('#' + panorama_div).css({
					'width': w + 'px',
					'height': h + 'px'
				});
			}
			pannellum.viewer(panorama_div, panorama_config);
			return false;
		}
		<?php } ?>
		var pano_<?php echo $div_seq; ?> = {
			'type': '<?php echo $atts['type']; ?>',
			'title': '<?php echo $atts['title']; ?>',
			'hfov': <?php echo $atts['hfov']; ?>,
			'minHfov': <?php echo $atts['minhfov']; ?>,
			'maxHfov': <?php echo $atts['maxhfov']; ?>,
			'haov': <?php echo $atts['haov']; ?>,
			'vaov': <?php echo $atts['vaov']; ?>,
			'voffset': <?php echo $atts['voffset']; ?>,
			'pitch': <?php echo $atts['pitch']; ?>,
			'yaw': <?php echo $atts['yaw']; ?>,
			'minPitch': <?php echo $atts['minpitch']; ?>,
			'maxPitch': <?php echo $atts['maxpitch']; ?>,
			'minYaw': <?php echo $atts['minyaw']; ?>,
			'maxYaw': <?php echo $atts['maxyaw']; ?>,
			'autoRotate': <?php echo $atts['autorotate']; ?>,
			'showZoomCtrl' : <?php echo $atts['showzoomctrl']; ?>,
			'showFullscreenCtrl' : <?php echo $atts['showfullscreenctrl']; ?>,
			'panorama': '<?php echo $atts['url']; ?>',
			'autoLoad': <?php echo $atts['autoload']; ?>,
			'autoRotateInactivityDelay': <?php echo $atts['autorotateinactivitydelay']; ?>}
		<?php if ($atts['popup_view'] === '') { ?>
			show_pannellum('<?php echo $pannellum_div; ?>', <?php echo $pano_config; ?>, '<?php echo $atts['popup_view']; ?>', <?php echo $ratio; ?>);
		<?php } ?>
	</script>
<?php
	if ($div_seq == 1) 
		echo "<div id='wp_pannellum_bg'></div><div id='wp_pannellum_popup'><div id='wp_pannellum_close'></div><div id='panorama' style='width:100%; height:100%;'></div></div>";
	if ($atts['popup_view'] !== '')
		echo "<a href='javascript:void(0);' onclick=\"show_pannellum('panorama'," . $pano_config . ",'1' ," . $ratio . ");\">" . $atts['anchor_text'] . "</a>";
	$s = ob_get_contents();
	ob_end_clean();
	return $s;
}
add_shortcode('wp_pannellum', 'wp_pannellum_func' );

